@@ -1,23 +1,23 @@
 /*
-* This file is part of the QPackageKit project
-* Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
-* Copyright (C) 2010-2011 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
-*
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Library General Public
-* License as published by the Free Software Foundation; either
-* version 2 of the License, or (at your option) any later version.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Library General Public License for more details.
-*
-* You should have received a copy of the GNU Library General Public License
-* along with this library; see the file COPYING.LIB. If not, write to
-* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
-*/
+ * This file is part of the QPackageKit project
+ * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
+ * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB. If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "daemon.h"
 #include "daemonprivate.h"
@@ -26,6 +26,8 @@
 
 #include "common.h"
 
+Q_LOGGING_CATEGORY(PACKAGEKITQT_DAEMON, "packagekitqt.daemon")
+
 using namespace PackageKit;
 
 Daemon* Daemon::m_global = 0;
@@ -57,37 +59,37 @@ Daemon::Daemon(QObject *parent) :
                                          SLOT(propertiesChanged(QString,QVariantMap,QStringList)));
 }
 
-void DaemonPrivate::setupSignal(const QString &signal, bool connect)
+void DaemonPrivate::setupSignal(const QMetaMethod &signal, bool connect)
 {
     Q_Q(Daemon);
 
     const char *signalToConnect = 0;
     const char *memberToConnect = 0;
 
-    if (signal == SIGNAL(repoListChanged())) {
+    if (signal == QMetaMethod::fromSignal(&Daemon::repoListChanged)) {
         signalToConnect = SIGNAL(RepoListChanged());
         memberToConnect = SIGNAL(repoListChanged());
-    } else if (signal == SIGNAL(restartScheduled())) {
+    } else if (signal == QMetaMethod::fromSignal(&Daemon::restartScheduled)) {
         signalToConnect = SIGNAL(RestartSchedule());
         memberToConnect = SIGNAL(restartScheduled());
-    } else if (signal == SIGNAL(transactionListChanged(QStringList))) {
+    } else if (signal == QMetaMethod::fromSignal(&Daemon::transactionListChanged)) {
         signalToConnect = SIGNAL(TransactionListChanged(QStringList));
         memberToConnect = SIGNAL(transactionListChanged(QStringList));
-    } else if (signal == SIGNAL(updatesChanged())) {
+    } else if (signal == QMetaMethod::fromSignal(&Daemon::updatesChanged)) {
         signalToConnect = SIGNAL(UpdatesChanged());
         memberToConnect = SIGNAL(updatesChanged());
     }
 
     if (signalToConnect && memberToConnect) {
         if (connect) {
-            q->connect(daemon, signalToConnect, memberToConnect);
+            QObject::connect(daemon, signalToConnect, q, memberToConnect);
         } else {
-            daemon->disconnect(signalToConnect, q, memberToConnect);
+            QObject::disconnect(daemon, signalToConnect, q, memberToConnect);
         }
     }
 }
 
-void Daemon::connectNotify(const char *signal)
+void Daemon::connectNotify(const QMetaMethod &signal)
 {
     Q_D(Daemon);
     if (!d->connectedSignals.contains(signal) && d->daemon) {
@@ -96,16 +98,7 @@ void Daemon::connectNotify(const char *signal)
     d->connectedSignals << signal;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-void Daemon::connectNotify(const QMetaMethod &signal)
-{
-    // ugly but recommended way to convert a methodSignature to a SIGNAL
-    connectNotify(QString("2%1")
-                  .arg(QLatin1String(signal.methodSignature())).toLatin1());
-}
-#endif
-
-void Daemon::disconnectNotify(const char *signal)
+void Daemon::disconnectNotify(const QMetaMethod &signal)
 {
     Q_D(Daemon);
     if (d->connectedSignals.contains(signal)) {
@@ -116,15 +109,6 @@ void Daemon::disconnectNotify(const char *signal)
     }
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-void Daemon::disconnectNotify(const QMetaMethod &signal)
-{
-    // ugly but recommended way to convert a methodSignature to a SIGNAL
-    disconnectNotify(QString("2%1")
-                     .arg(QLatin1String(signal.methodSignature())).toLatin1());
-}
-#endif
-
 Daemon::~Daemon()
 {
     delete d_ptr;
@@ -655,5 +639,77 @@ Transaction *Daemon::whatProvides(const QString &search, Transaction::Filters fi
     return whatProvides(QStringList() << search, filters);
 }
 
-#include "daemon.moc"
+QString Daemon::enumToString(const QMetaObject &metaObject, int value, const char *enumName)
+{
+    QString prefix = QLatin1String(enumName);
+    int id = metaObject.indexOfEnumerator(enumName);
+    QMetaEnum e = metaObject.enumerator(id);
+    if (!e.isValid ()) {
+//         qDebug() << "Invalid enum " << prefix;
+        return QString();
+    }
+    QString enumString = QString::fromLatin1(e.valueToKey(value));
+    if (enumString.isNull()) {
+//         qDebug() << "Enum key not found while searching for value" << QString::number(value) << "in enum" << prefix;
+        return QString();
+    }
+
+    // Remove the prefix
+    if(!prefix.isNull() && enumString.indexOf(prefix) == 0) {
+        enumString.remove(0, prefix.length());
+    }
+
+    QString pkName;
+    for(int i = 0 ; i < enumString.length() - 1 ; ++i) {
+        pkName += enumString[i];
+        if(enumString[i+1].isUpper())
+            pkName += QLatin1Char('-');
+    }
+    pkName += enumString[enumString.length() - 1];
+
+    return pkName.toLower();
+}
+
+int Daemon::enumFromString(const QMetaObject& metaObject, const QString &str, const char *enumName)
+{
+    QString prefix = QLatin1String(enumName);
+    QString realName;
+    bool lastWasDash = false;
+    QChar buf;
+
+    for(int i = 0 ; i < str.length() ; ++i) {
+        buf = str[i].toLower();
+        if(i == 0 || lastWasDash) {
+            buf = buf.toUpper();
+        }
+
+        lastWasDash = false;
+        if(buf == QLatin1Char('-')) {
+            lastWasDash = true;
+        } else if(buf == QLatin1Char('~')) {
+            lastWasDash = true;
+            realName += QLatin1String("Not");
+        } else {
+            realName += buf;
+        }
+    };
+
+    if (!prefix.isNull()) {
+        realName = prefix + realName;
+    }
+
+    int id = metaObject.indexOfEnumerator(enumName);
+    QMetaEnum e = metaObject.enumerator(id);
+    int enumValue = e.keyToValue(realName.toLatin1().data());
+
+    if (enumValue == -1) {
+        enumValue = e.keyToValue(prefix.append(QLatin1String("Unknown")).toLatin1().constData());
+//         if (!QByteArray(enumName).isEmpty()) {
+//             qDebug() << "enumFromString (" << enumName << ") : converted" << str << "to" << QString("Unknown").append(enumName) << ", enum id" << id;
+//         }
+    }
+    return enumValue;
+}
+
+#include "moc_daemon.cpp"
 
