@@ -1,7 +1,7 @@
 /*
  * This file is part of the QPackageKit project
  * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
- * Copyright (C) 2010-2011 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
+ * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -81,7 +81,7 @@ void DaemonPrivate::getAllProperties(bool sync)
                                                           QLatin1String(PK_PATH),
                                                           QLatin1String(DBUS_PROPERTIES),
                                                           QLatin1String("GetAll"));
-    message << PK_NAME;
+    message << QLatin1String(PK_NAME);
     if (sync) {
         QDBusReply<QVariantMap> reply = QDBusConnection::systemBus().call(message);
         if (reply.isValid()) {
@@ -143,7 +143,7 @@ void DaemonPrivate::updateProperties(const QVariantMap &properties)
         } else if (property == QLatin1String("VersionMinor")) {
             versionMinor = value.toUInt();
         } else {
-            qWarning() << "Unknown Transaction property:" << property << value;
+            qCWarning(PACKAGEKITQT_DAEMON) << "Unknown Daemon property:" << property << value;
         }
 
         ++it;
