@@ -28,6 +28,8 @@
 
 #include <QDBusError>
 
+Q_LOGGING_CATEGORY(PACKAGEKITQT_TRANSACTION, "packagekitqt.transaction")
+
 using namespace PackageKit;
 
 Transaction::Transaction()
@@ -50,7 +52,7 @@ Transaction::Transaction(const QDBusObjectPath &tid)
     d->setup(tid);
 }
 
-void Transaction::connectNotify(const char *signal)
+void Transaction::connectNotify(const QMetaMethod &signal)
 {
     Q_D(Transaction);
     if (!d->connectedSignals.contains(signal) && d->p) {
@@ -59,16 +61,7 @@ void Transaction::connectNotify(const char *signal)
     d->connectedSignals << signal;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-void Transaction::connectNotify(const QMetaMethod &signal)
-{
-    // ugly but recommended way to convert a methodSignature to a SIGNAL
-    connectNotify(QString("2%1")
-                  .arg(QLatin1String(signal.methodSignature())).toLatin1());
-}
-#endif
-
-void Transaction::disconnectNotify(const char *signal)
+void Transaction::disconnectNotify(const QMetaMethod &signal)
 {
     Q_D(Transaction);
     if (d->connectedSignals.contains(signal)) {
@@ -79,82 +72,73 @@ void Transaction::disconnectNotify(const char *signal)
     }
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-void Transaction::disconnectNotify(const QMetaMethod &signal)
-{
-    // ugly but recommended way to convert a methodSignature to a SIGNAL
-    disconnectNotify(QString("2%1")
-                     .arg(QLatin1String(signal.methodSignature())).toLatin1());
-}
-#endif
-
 Transaction::Transaction(TransactionPrivate *d)
     : d_ptr(d)
 {
 }
 
-void TransactionPrivate::setupSignal(const QString &signal, bool connect)
+void TransactionPrivate::setupSignal(const QMetaMethod &signal, bool connect)
 {
     Q_Q(Transaction);
 
     const char *signalToConnect = 0;
     const char *memberToConnect = 0;
 
-    if (signal == SIGNAL(category(QString,QString,QString,QString,QString))) {
+    if (signal == QMetaMethod::fromSignal(&Transaction::category)) {
         signalToConnect = SIGNAL(Category(QString,QString,QString,QString,QString));
         memberToConnect = SIGNAL(category(QString,QString,QString,QString,QString));
-    } else if (signal == SIGNAL(details(PackageKit::Details))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::details)) {
         signalToConnect = SIGNAL(Details(QVariantMap));
         memberToConnect = SLOT(details(QVariantMap));
-    } else if (signal == SIGNAL(distroUpgrade(PackageKit::Transaction::DistroUpgrade,QString,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::distroUpgrade)) {
         signalToConnect = SIGNAL(DistroUpgrade(uint,QString,QString));
         memberToConnect = SLOT(distroUpgrade(uint,QString,QString));
-    } else if (signal == SIGNAL(errorCode(PackageKit::Transaction::Error,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::errorCode)) {
         signalToConnect = SIGNAL(ErrorCode(uint,QString));
         memberToConnect = SLOT(errorCode(uint,QString));
-    } else if (signal == SIGNAL(files(QString,QStringList))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::files)) {
         signalToConnect = SIGNAL(Files(QString,QStringList));
         memberToConnect = SIGNAL(files(QString,QStringList));
-    } else if (signal == SIGNAL(finished(PackageKit::Transaction::Exit,uint))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::finished)) {
         signalToConnect = SIGNAL(Finished(uint,uint));
         memberToConnect = SLOT(finished(uint,uint));
-    } else if (signal == SIGNAL(message(PackageKit::Transaction::Message,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::message)) {
         signalToConnect = SIGNAL(Message(uint,QString));
         memberToConnect = SLOT(message(uint,QString));
-    } else if (signal == SIGNAL(package(PackageKit::Transaction::Info,QString,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::package)) {
         signalToConnect = SIGNAL(Package(uint,QString,QString));
         memberToConnect = SLOT(Package(uint,QString,QString));
-    } else if (signal == SIGNAL(repoDetail(QString,QString,bool))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::repoDetail)) {
         signalToConnect = SIGNAL(RepoDetail(QString,QString,bool));
         memberToConnect = SIGNAL(repoDetail(QString,QString,bool));
-    } else if (signal == SIGNAL(repoSignatureRequired(QString,QString,QString,QString,QString,QString,QString,PackageKit::Transaction::SigType))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::repoSignatureRequired)) {
         signalToConnect = SIGNAL(RepoSignatureRequired(QString,QString,QString,QString,QString,QString,QString,uint));
         memberToConnect = SLOT(RepoSignatureRequired(QString,QString,QString,QString,QString,QString,QString,uint));
-    } else if (signal == SIGNAL(eulaRequired(QString,QString,QString,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::eulaRequired)) {
         signalToConnect = SIGNAL(EulaRequired(QString,QString,QString,QString));
         memberToConnect = SIGNAL(eulaRequired(QString,QString,QString,QString));
-    } else if (signal == SIGNAL(mediaChangeRequired(PackageKit::Transaction::MediaType,QString,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::mediaChangeRequired)) {
         signalToConnect = SIGNAL(MediaChangeRequired(uint,QString,QString));
         memberToConnect = SLOT(mediaChangeRequired(uint,QString,QString));
-    } else if (signal == SIGNAL(itemProgress(QString,PackageKit::Transaction::Status,uint))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::itemProgress)) {
         signalToConnect = SIGNAL(ItemProgress(QString,uint,uint));
         memberToConnect = SLOT(ItemProgress(QString,uint,uint));
-    } else if (signal == SIGNAL(requireRestart(PackageKit::Transaction::Restart,QString))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::requireRestart)) {
         signalToConnect = SIGNAL(RequireRestart(uint,QString));
         memberToConnect = SLOT(requireRestart(uint,QString));
-    } else if (signal == SIGNAL(transaction(PackageKit::Transaction*))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::transaction)) {
         signalToConnect = SIGNAL(Transaction(QDBusObjectPath,QString,bool,uint,uint,QString,uint,QString));
         memberToConnect = SLOT(transaction(QDBusObjectPath,QString,bool,uint,uint,QString,uint,QString));
-    } else if (signal == SIGNAL(updateDetail(QString,QStringList,QStringList,QStringList,QStringList,QStringList,PackageKit::Transaction::Restart,QString,QString,PackageKit::Transaction::UpdateState,QDateTime,QDateTime))) {
+    } else if (signal == QMetaMethod::fromSignal(&Transaction::updateDetail)) {
         signalToConnect = SIGNAL(UpdateDetail(QString,QStringList,QStringList,QStringList,QStringList,QStringList,uint,QString,QString,uint,QString,QString));
         memberToConnect = SLOT(UpdateDetail(QString,QStringList,QStringList,QStringList,QStringList,QStringList,uint,QString,QString,uint,QString,QString));
     }
 
     if (signalToConnect && memberToConnect) {
         if (connect) {
-            q->connect(p, signalToConnect, memberToConnect);
+            QObject::connect(p, signalToConnect, q, memberToConnect);
         } else {
-            p->disconnect(signalToConnect, q, memberToConnect);
+            QObject::disconnect(p, signalToConnect, q, memberToConnect);
         }
     }
 }
@@ -353,9 +337,9 @@ Transaction::InternalError Transaction::parseError(const QString &errorName)
         return Transaction::InternalErrorFunctionNotSupported;
     }
 
-    qWarning() << "Transaction::parseError: unknown error" << errorName;
+    qCWarning(PACKAGEKITQT_TRANSACTION) << "Transaction::parseError: unknown error" << errorName;
     return Transaction::InternalErrorFailed;
 }
 
-#include "transaction.moc"
+#include "moc_transaction.cpp"
 
