@@ -1,7 +1,7 @@
 /*
  * This file is part of the QPackageKit project
  * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
- * Copyright (C) 2010-2011 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
+ * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -61,7 +61,7 @@ void TransactionPrivate::setup(const QDBusObjectPath &transactionId)
                                                           tid.path(),
                                                           QLatin1String(DBUS_PROPERTIES),
                                                           QLatin1String("GetAll"));
-    message << PK_TRANSACTION_INTERFACE;
+    message << QLatin1String(PK_TRANSACTION_INTERFACE);
     QDBusConnection::systemBus().callWithCallback(message,
                                                   q,
                                                   SLOT(updateProperties(QVariantMap)));
@@ -74,9 +74,7 @@ void TransactionPrivate::setup(const QDBusObjectPath &transactionId)
                                          q,
                                          SLOT(propertiesChanged(QString,QVariantMap,QStringList)));
 
-    QStringList currentSignals = connectedSignals;
-    currentSignals.removeDuplicates();
-    foreach (const QString &signal, currentSignals) {
+    foreach (const QMetaMethod &signal, connectedSignals) {
         setupSignal(signal, true);
     }
 
@@ -335,7 +333,7 @@ void TransactionPrivate::updateProperties(const QVariantMap &properties)
             uid = value.toUInt();
             QMetaObject::invokeMethod(q, "uidChanged", Qt::QueuedConnection);
         } else {
-            qWarning() << "Unknown Transaction property:" << property << value;
+            qCWarning(PACKAGEKITQT_TRANSACTION) << "Unknown Transaction property:" << property << value;
         }
 
         ++it;
