@@ -1,7 +1,7 @@
 /*
  * This file is part of the QPackageKit project
  * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
- * Copyright (C) 2010-2011 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
+ * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -47,7 +47,7 @@ protected:
     QDBusObjectPath tid;
     ::OrgFreedesktopPackageKitTransactionInterface* p = 0;
     Transaction *q_ptr;
-    QStringList connectedSignals;
+    QList<QMetaMethod> connectedSignals;
 
     bool sentFinished = false;
     bool allowCancel = false;
@@ -88,7 +88,11 @@ protected:
     QString data;
     QString cmdline;
 
-    void setupSignal(const QString &signal, bool connect);
+    void setupSignal(const QMetaMethod &signal, bool connect);
+
+private:
+    template <typename Func1, typename Func2>
+    void processConnect(bool connect, Func1 signal, Func2 slot);
 
 protected Q_SLOTS:
     void createTransactionFinished(QDBusPendingCallWatcher *call);
